@@ -174,10 +174,10 @@
 #' `..$call` : \tab `call` \tab The original function call\cr
 #' }
 #'
-#' @section Function version: 1.10.4
+#' @section Function version: 1.10.6
 #'
 #' @author
-#' Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)\cr
+#' Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, CNRS - Université Bordeaux Montaigne (France)\cr
 #' Michael Dietze, GFZ Potsdam (Germany)
 #'
 #' @references
@@ -308,7 +308,7 @@ plot_GrowthCurve <- function(
 
   ##2. check if sample contains a least three rows
   if(length(sample[[1]])<3 & fit.method != "LIN"){
-    stop("\n [plot_GrowthCurve()] At least two regeneration points are needed!")
+    stop("\n [plot_GrowthCurve()] At least two regeneration points are needed!", call. = FALSE)
   }
 
   ##2.1 check column numbers; we assume that in this particular case no error value
@@ -495,15 +495,14 @@ plot_GrowthCurve <- function(
     data <-
       data.frame(x = xy[[1]][!duplicated(xy[[1]])], y = xy[[2]][!duplicated(xy[[1]])])
     fit.weights <- fit.weights[!duplicated(xy[[1]])]
-    data.MC <- data.MC[!duplicated(xy[[1]]),]
+    data.MC <- data.MC[!duplicated(xy[[1]]),,drop = FALSE]
     y.Error <- y.Error[!duplicated(xy[[1]])]
-    xy <- xy[!duplicated(xy[[1]]),]
+    xy <- xy[!duplicated(xy[[1]]),,drop = FALSE]
 
   }else{
     data <- data.frame(xy)
   }
 
-
   ## for unknown reasons with only two points the nls() function is trapped in
   ## an endless mode, therefore the minimum length for data is 3
   ## (2016-05-17)
@@ -533,9 +532,16 @@ plot_GrowthCurve <- function(
 
   ##b - get start parameters from a linear fit of the log(y) data
   ##    (suppress the warning in case one parameter is negative)
+  fit.lm <- try(lm(suppressWarnings(log(data$y))~data$x))
+
+  if(class(fit.lm) == "try-error"){
+    b <- 1
+
+  }else{
+    b <- as.numeric(1/fit.lm$coefficients[2])
+
+  }
 
-  fit.lm <- lm(suppressWarnings(log(data$y))~data$x)
-  b <- as.numeric(1/fit.lm$coefficients[2])
 
   ##c - get start parameters from a linear fit - offset on x-axis
   fit.lm<-lm(data$y~data$x)
@@ -555,7 +561,7 @@ plot_GrowthCurve <- function(
 
   ##draw 50 start values from a normal distribution a start values
   if (fit.method != "LIN") {
-    a.MC <- rnorm(50, mean = a, sd = a / 100)
+    a.MC <- suppressWarnings(rnorm(50, mean = a, sd = a / 100))
 
     if (!is.na(b)) {
       b.MC <- suppressWarnings(rnorm(50, mean = b, sd = b / 100))
@@ -565,8 +571,8 @@ plot_GrowthCurve <- function(
 
     }
 
-    c.MC <- rnorm(50, mean = c, sd = c / 100)
-    g.MC <- rnorm(50, mean = g, sd = g / 1)
+    c.MC <- suppressWarnings(rnorm(50, mean = c, sd = c / 100))
+    g.MC <- suppressWarnings(rnorm(50, mean = g, sd = g / 1))
 
     ##set start vector (to avoid errors witin the loop)
     a.start <- NA
@@ -665,7 +671,6 @@ plot_GrowthCurve <- function(
       pb<-txtProgressBar(min=0,max=NumberIterations.MC, char="=", style=3)
     }
 
-
     #start loop for Monte Carlo Error estimation
     fit.MC <- sapply(1:NumberIterations.MC, function(i){
 
@@ -757,7 +762,7 @@ plot_GrowthCurve <- function(
   if (fit.method=="EXP" | fit.method=="EXP OR LIN" | fit.method=="LIN"){
 
     if((is.na(a) | is.na(b) | is.na(c)) && fit.method != "LIN"){
-      try(stop("[plot_GrowthCurve()] Fit could not applied for this data set. NULL returned!", call. = FALSE))
+      try(stop("[plot_GrowthCurve()] Fit could not be applied for this data set. NULL returned!", call. = FALSE))
       return(NULL)
 
     }
@@ -1020,8 +1025,7 @@ plot_GrowthCurve <- function(
       #start loop for Monte Carlo Error estimation
       #LIN MC ---------
       for (i in 1:NumberIterations.MC) {
-
-        data <- data.frame(x=xy$x, y=data.MC[,i])
+        data <- data.frame(x = xy$x, y = data.MC[, i])
 
         if(fit.force_through_origin){
 
