@@ -4,39 +4,39 @@
 #' RLum.Data.Curve S4 class object
 #'
 #' Only single curve data can be plotted with this function.  Arguments
-#' according to \code{\link{plot}}.
+#' according to [plot].
 #'
-#' @param object \code{\linkS4class{RLum.Data.Curve}} (\bold{required}): S4
-#' object of class \code{RLum.Data.Curve}
+#' @param object [RLum.Data.Curve-class] (**required**): 
+#' S4 object of class `RLum.Data.Curve`
 #'
-#' @param par.local \code{\link{logical}} (with default): use local graphical
-#' parameters for plotting, e.g. the plot is shown in one column and one row.
-#' If \code{par.local = FALSE}, global parameters are inherited.
+#' @param par.local [logical] (*with default*): 
+#' use local graphical parameters for plotting, e.g. the plot is shown in one 
+#' column and one row. If `par.local = FALSE`, global parameters are inherited.
 #'
-#' @param norm \code{\link{logical}} (with default): allows curve normalisation
-#' to the highest count value
+#' @param norm [logical] (*with default*): 
+#' allows curve normalisation to the highest count value
 #'
-#' @param \dots further arguments and graphical parameters that will be passed
-#' to the \code{plot} function
+#' @param smooth [logical] (*with default*): 
+#' provides an automatic curve smoothing based on [zoo::rollmean]
+#'
+#' @param ... further arguments and graphical parameters that will be passed
+#' to the `plot` function
 #'
 #' @return Returns a plot.
 #'
-#' @note Not all arguments of \code{\link{plot}} will be passed!
+#' @note Not all arguments of [plot] will be passed!
 #'
-#' @section Function version: 0.1.6
+#' @section Function version: 0.2.3
 #'
-#' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
-#' (France)
+#' @author 
+#' Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
 #'
-#' @seealso \code{\link{plot}}, \code{\link{plot_RLum}}
-#'
-#' @references #
+#' @seealso [plot], [plot_RLum]
 #'
 #' @keywords aplot
 #'
 #' @examples
 #'
-#'
 #' ##plot curve data
 #'
 #' #load Example data
@@ -49,11 +49,13 @@
 #' plot_RLum.Data.Curve(temp)
 #'
 #'
+#' @md
 #' @export
 plot_RLum.Data.Curve<- function(
   object,
   par.local = TRUE,
   norm = FALSE,
+  smooth = FALSE,
   ...
 ){
 
@@ -61,55 +63,73 @@ plot_RLum.Data.Curve<- function(
 
   ##check if object is of class RLum.Data.Curve
   if(class(object) != "RLum.Data.Curve"){
-
     stop("[plot_RLum.Data.Curve()] Input object is not of type RLum.Data.Curve")
 
   }
 
   ##stop for NA values
-  if (!anyNA(object@data)) {
+  if (!all(is.na(object@data))) {
+
     ##set labeling unit
-    lab.unit <- if (object@recordType == "OSL" |
-                    object@recordType == "IRSL" |
-                    object@recordType == "RL" |
-                    object@recordType == "RF" |
-                    object@recordType == "LM-OSL" |
-                    object@recordType == "RBR") {
-      "s"
-    }
-    else if (object@recordType == "TL") {
-      "\u00B0C"
-    }
-    else {
-      "Unknown"
+    if(!is.na(object@recordType)){
+      lab.unit <- if (object@recordType == "OSL" |
+                      object@recordType == "IRSL" |
+                      object@recordType == "RL" |
+                      object@recordType == "RF" |
+                      object@recordType == "LM-OSL" |
+                      object@recordType == "RBR") {
+        "s"
+      } else if (object@recordType == "TL") {
+        "\u00B0C"
+      }
+      else {
+        "Unknown"
+      }
+    }else{
+      lab.unit <- "Unknown"
+
     }
 
-    lab.xlab <- if (object@recordType == "OSL" |
-                    object@recordType == "IRSL" |
-                    object@recordType == "RL" |
-                    object@recordType == "RF" |
-                    object@recordType == "RBR") {
-      "Stimulation time"
-    }
-    else if (object@recordType == "TL") {
-      "Temperature"
-    }
-    else {
-      "Independent"
+    if(!is.na(object@recordType)){
+      lab.xlab <- if (object@recordType == "OSL" |
+                      object@recordType == "IRSL" |
+                      object@recordType == "RL" |
+                      object@recordType == "RF" |
+                      object@recordType == "RBR" |
+                      object@recordType == "LM-OSL"){
+
+        "Stimulation time"
+      }
+      else if (object@recordType == "TL") {
+        "Temperature"
+      }
+      else {
+        "Independent"
+      }
+    }else{
+      lab.xlab <- "Independent"
+
     }
 
     ##XSYG
     ##check for curveDescripter
-    if ("curveDescripter" %in% names(object@info) == TRUE) {
-      temp.lab <- strsplit(object@info$curveDescripter, split = ";")[[1]]
+    if ("curveDescripter" %in% names(object@info)) {
+      temp.lab <-
+        strsplit(object@info$curveDescripter,
+                 split = ";",
+                 fixed = TRUE)[[1]]
 
-      xlab <- temp.lab[1]
-      ylab <- temp.lab[2]
+      xlab.xsyg <- temp.lab[1]
+      ylab.xsyg <- temp.lab[2]
+
+    } else{
+      xlab.xsyg <- NA
+      ylab.xsyg <- NA
 
     }
 
     ##normalise curves if argument has been set
-    if (norm == TRUE) {
+    if (norm) {
       object@data[,2] <- object@data[,2] / max(object@data[,2])
 
     }
@@ -128,19 +148,18 @@ plot_RLum.Data.Curve<- function(
       extraArgs$xlab
     } else
     {
-      if (exists("xlab") == TRUE) {
-        xlab
+      if (!is.na(xlab.xsyg)) {
+        xlab.xsyg
       } else
       {
-        paste(lab.xlab," [",lab.unit,"]", sep = "")
+        paste0(lab.xlab, " [", lab.unit, "]")
       }
     }
 
     ylab <- if ("ylab" %in% names(extraArgs)) {
       extraArgs$ylab
-    }
-    else if (exists("ylab") == TRUE) {
-      ylab
+    }else if (!is.na(ylab.xsyg)) {
+      ylab.xsyg
     }
     else if (lab.xlab == "Independent") {
       "Dependent [unknown]"
@@ -216,7 +235,7 @@ plot_RLum.Data.Curve<- function(
       extraArgs$ylim
     } else
     {
-      c(min(object@data[,2]),max(object@data[,2]))
+      c(min(object@data[,2], na.rm = TRUE),max(object@data[,2], na.rm = TRUE))
     }
 
     xlim <- if ("xlim" %in% names(extraArgs)) {
@@ -240,7 +259,7 @@ plot_RLum.Data.Curve<- function(
       ""
     }
 
-    fun       <-
+    fun  <-
       if ("fun" %in% names(extraArgs)) {
         extraArgs$fun
       } else {
@@ -261,6 +280,15 @@ plot_RLum.Data.Curve<- function(
       par(mfrow = c(1,1), cex = cex)
     }
 
+    ##smooth
+    if(smooth){
+
+      k <- ceiling(length(object@data[, 2])/100)
+      object@data[, 2] <- zoo::rollmean(object@data[, 2],
+                                        k = k, fill = NA)
+    }
+
+
     ##plot curve
     plot(
       object@data[,1], object@data[,2],
@@ -286,8 +314,7 @@ plot_RLum.Data.Curve<- function(
     }
 
   }else{
-
-    warning("[plot_RLum.Data.Curve()] Curve contains NA-values, nothing plotted.")
+    warning("[plot_RLum.Data.Curve()] Curve contains only NA-values, nothing plotted.", call. = FALSE)
 
   }
 
